-- Clear old data
DROP TABLE IF EXISTS exp_pa_event;
DROP TABLE IF EXISTS exp_plesk_event;

-- Create our data
DROP TABLE IF EXISTS exp_event;
CREATE TABLE exp_event (
	source		ENUM('pa', 'plesk'),	-- Event producer

	event_type	ENUM(
				'started', 'stopped',
				'created', 'updated', 'deleted', 'status_changed',
				'terminated', 'flushed',
				'installed', 'uninstalled',
				'siteapp_added', 'siteapp_removed',
				'expired'
			) NOT NULL,		-- Type of event occurred
	event_time	DATETIME NOT NULL,	-- Time of event occurred

	obj_class	ENUM(
				-- Server-related objects
				'license', 'service', 'ip_address',
				'admin_info', 'siteapp',
				-- Clients-related objects
				'client', 'client_limits', 'client_status',
				'client_prefs', 'client_perms',
				'client_ip_pool',
				-- Domains-related objects
				'domain', 'domain_limits', 'domain_user',
				'domain_status', 'phosting', 'fhosting',
				'subdomain', 'mailname', 'webuser',
				'maillist', 'dns_zone',
				'mailname_antivirus',
				'mailname_spamfilter',
				'mailname_mailgroup',
				'mailname_autoresponder',
				'mailname_attachment'
			) NOT NULL,		-- Evented object class
	obj_id		VARCHAR(255),		-- Evented object unique ID

	INDEX (source, event_type),
	INDEX (source, event_type, obj_class),
	INDEX (source, event_time, event_type, obj_class)
);
